@@ -244,10 +244,13 @@ class TikTokApi:
     #
 
     def getUserObject(self, username, language='en'):
+        return self.getUser(username, language)['userInfo']['user']
+
+    def getUser(self, username, language='en'):
         api_url = "https://m.tiktok.com/api/user/detail/?uniqueId={}&language={}&verifyFp=".format(
             username, language)
         b = browser(api_url)
-        return self.getData(api_url, b.signature, b.userAgent)['userInfo']['user']
+        return self.getData(api_url, b.signature, b.userAgent)
 
     #
     # Downloads video from TikTok using a TikTok object
@@ -332,5 +335,4 @@ class TikTokApi:
                 return b.redirect_url
             else:
                 r = requests.get(b.redirect_url)
-                return r.content
-                
+                return r.content
\ No newline at end of file
